"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LcmGenerationStyle(str, Enum):
    r"""The style to generate LCM images with."""

    ANIME = "ANIME"
    CINEMATIC = "CINEMATIC"
    DIGITAL_ART = "DIGITAL_ART"
    DYNAMIC = "DYNAMIC"
    ENVIRONMENT = "ENVIRONMENT"
    FANTASY_ART = "FANTASY_ART"
    ILLUSTRATION = "ILLUSTRATION"
    PHOTOGRAPHY = "PHOTOGRAPHY"
    RENDER_3_D = "RENDER_3D"
    RAYTRACED = "RAYTRACED"
    SKETCH_BW = "SKETCH_BW"
    SKETCH_COLOR = "SKETCH_COLOR"
    VIBRANT = "VIBRANT"
    NONE = "NONE"
