"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomModelType(str, Enum):
    r"""The category the most accurately reflects the model."""

    GENERAL = "GENERAL"
    BUILDINGS = "BUILDINGS"
    CHARACTERS = "CHARACTERS"
    ENVIRONMENTS = "ENVIRONMENTS"
    FASHION = "FASHION"
    ILLUSTRATIONS = "ILLUSTRATIONS"
    GAME_ITEMS = "GAME_ITEMS"
    GRAPHICAL_ELEMENTS = "GRAPHICAL_ELEMENTS"
    PHOTOGRAPHY = "PHOTOGRAPHY"
    PIXEL_ART = "PIXEL_ART"
    PRODUCT_DESIGN = "PRODUCT_DESIGN"
    TEXTURES = "TEXTURES"
    UI_ELEMENTS = "UI_ELEMENTS"
    VECTOR = "VECTOR"
