"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UniversalUpscalerUltraStyle(str, Enum):
    r"""The ultra style to upscale images using universal upscaler with. Can not be used with upscalerStyle."""

    ARTISTIC = "ARTISTIC"
    REALISTIC = "REALISTIC"
