"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UniversalUpscalerStyle(str, Enum):
    r"""The style to upscale images using universal upscaler with. Can not be used with ultraUpscaleStyle."""

    GENERAL = "GENERAL"
    CINEMATIC = "CINEMATIC"
    TWO_D_ART_AND_ILLUSTRATION = "2D ART & ILLUSTRATION"
    CG_ART_AND_GAME_ASSETS = "CG ART & GAME ASSETS"
