"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ModelAssetTextureTypes(str, Enum):
    r"""When training model assets these are the texture types available to use."""

    ALBEDO = "ALBEDO"
    NORMAL = "NORMAL"
    ROUGHNESS = "ROUGHNESS"
    DISPLACEMENT = "DISPLACEMENT"
    HDRP_MASK = "HDRP_MASK"
